{% extends "analysis.html" %}


{% block head %}
<link rel="stylesheet" href="/_static/databench.css?v={{databench_version}}">
{% end %}


{% block analysis %}
<div>
    <video id="video" style="display: none" controls autoplay></video>
    <canvas id="canvas-capture" style="display: none" width=640 height=480></canvas>
    <canvas id="canvas-out" width=320 height=240></canvas>
    <br />
    <label for="resolution">Resolution:</label>
    <input type="range" id="resolution" value="10" min="10" max="200" step="5" />
</div>

<div style="font-size: 200%">
    FPS = <em><span id="fps">0</span></em>
</div>
{% end %}


{% block log %}
{% end %}


{% block footer %}
<script src="/_static/databench.js?v={{databench_version}}"></script>
<script src="/analysis.js?v={{version}}"></script>
{% end %}
